@@ -1,3 +1,6 @@
+import requests
+from bs4 import BeautifulSoup
+
 def bian(url):
     # 获取源代码
     r = requests.get(url)
